List all available challenge ids
list_challenges.RdReturns the ids of every challenge currently registered in the
package. Use an id with run_challenge() to attempt that challenge.
list_challenges.RdReturns the ids of every challenge currently registered in the
package. Use an id with run_challenge() to attempt that challenge.